<?php

class file {

    public static function add($name, $guide, $icon, $binary, $config) {
        if ($name == "") {
            error::occur('file_add_name_empty');
            return false;
        }
        if ($icon) {
            $icon = self::cleanup_url($icon);
        }
        if ($binary) {
            $binary = self::cleanup_url($binary);
        }
        if ($config) {
            $config = self::cleanup_url($config);
        }
        $tbl = ORM::for_table('file')
                ->create();
        $tbl->name = $name;
        $tbl->guide = $guide;
        $tbl->icon = $icon;
        $tbl->binary = $binary;
        $tbl->config = $config;
        try {
            $tbl->save();
            notice::occur('file_add_success');
            return true;
        } catch (Exception $ex) {
            error::occur($ex->getMessage());
            return false;
        }
    }

    public static function lists() {
        $tbl = ORM::for_table('file')
                ->find_many();
        return $tbl;
    }

    public static function delete($file_id) {
        $tbl = ORM::for_table('file')
                ->where('id', $file_id)
                ->find_one();
        try {
            $tbl->delete();
            notice::occur('file_delete_success');
            return true;
        } catch (Exception $ex) {
            error::occur('file_delete_failed');
            return false;
        }
    }

    public static function edit($file_id, $name, $guide, $icon, $binary, $config) {
        if ($name == "") {
            error::occur('file_add_name_empty');
            return false;
        }
        if ($icon) {
            $icon = self::cleanup_url($icon);
        }
        if ($binary) {
            $binary = self::cleanup_url($binary);
        }
        if ($config) {
            $config = self::cleanup_url($config);
        }
        $tbl = ORM::for_table('file')
                ->where('id', $file_id)
                ->find_one();
        $tbl->name = $name;
        $tbl->guide = $guide;
        $tbl->icon = $icon;
        $tbl->binary = $binary;
        $tbl->config = $config;
        try {
            $tbl->save();
            notice::occur('file_edit_success');
            return true;
        } catch (Exception $ex) {
            error::occur($ex->getMessage());
            return false;
        }
    }

    //returns object model of table
    public static function info($file_id) {
        $tbl = ORM::for_table('file')
                ->where('id', $file_id)
                ->find_one();
        $tbl->binary_basename = basename($tbl->binary);
        $tbl->config_basename = basename($tbl->config);
        return $tbl;
    }

    public static function cleanup_url($url) {
        $parts = parse_url($url);
        return $parts['path'];
    }

}
